@@ -2,25 +2,15 @@
 # PODNAME: es-copy-index.pl
 # ABSTRACT: Copy an index from one cluster to another
 
-BEGIN {
-    delete $ENV{$_} for qw(http_proxy https_proxy HTTP_PROXY);
-}
-
 use strict;
 use warnings;
 
 use Carp;
-use DateTime;
-use Elasticsearch::Compat;
-use File::Basename;
-use File::Spec;
-use FindBin;
-use Getopt::Long;
-use MIME::Lite;
+use Getopt::Long qw(:config posix_default no_ignore_case no_ignore_case_always);
 use Pod::Usage;
-use Sys::Hostname;
-use YAML;
-use App::ElasticSearch::Utilities qw(:all);
+
+use CLI::Helpers qw(:all);
+use App::ElasticSearch::Utilities qw(:default :index);
 
 #------------------------------------------------------------------------#
 # Argument Parsing
@@ -42,7 +32,6 @@ my $index = shift @ARGV;
 my %INDEX = (
     from => $index,
     to   => exists $OPT{rename} && length $OPT{rename} ? $OPT{rename} : $index,
-
 );
 
 # Check for valid use cases
@@ -53,52 +42,83 @@ if ( !defined($index) || !exists $OPT{from} || !exists $OPT{to} ) {
 # Connect to ElasticSearch
 my %ES = ();
 foreach my $dir (qw(from to)) {
-    $ES{$dir} = Elasticsearch::Compat->new(
-        servers   => "$OPT{$dir}:9200",
-        transport => 'http',
-        timeout   => 0,
-    );
+    $ES{$dir} = es_connect( [ "$OPT{$dir}:9200" ] );
 }
-croak "Invalid index: $index\n" unless valid_index($index);
+
+croak "Invalid index: $index\n" unless $ES{from}->exists( index => $INDEX{from} );
+
+croak "Index $INDEX{to} already exists in $OPT{to}\n" if $ES{to}->exists( index => $INDEX{to} );
+
 my $RECORDS = 0;
 my $LAST = time;
+my ($status, $res);
 
-my $scroller;
-eval {
-    $scroller = $ES{from}->scrolled_search(
-        index => $INDEX{from},
-        search_type => 'scan',
-        scroll => '5m',
-        size   => 500,
-    );
-};
-if( my $error = $@ ) {
-    croak "ElasticSearch error: $error";
+$res = $ES{from}->get( index => $INDEX{from} );
+my $settings = $res->{$index}{settings};
+my $mappings = $res->{$index}{mappings};
+
+($status, $res) = $ES{to}->put(
+    index => $INDEX{to},
+    body  => {
+        settings => {
+            index => {
+                number_of_shards => $settings->{index}{number_of_shards},
+                number_of_replicas => $settings->{index}{number_of_replicas},
+            }
+        },
+        mappings => $mappings,
+    }
+);
+
+require JSON;
+my $JSON = JSON->new->pretty->canonical;
+if ($status ne "200") {
+    croak "Failed to create index in $OPT{to} (http status = $status): " . $JSON->encode([ $status, $res ]);
 }
-eval {
-    $ES{to}->reindex(
-        source     => $scroller,
-        dest_index => $INDEX{to},
-        transform  => \&show_counts,
-        bulk_size  => 10000,
-        quiet      => !App::ElasticSearch::Utilities::def('verbose') > 0,
-    );
 
-    # Optimize
-    print "Optimizing $INDEX{to}.\n";
-    $ES{to}->optimize_index(
-        index            => $INDEX{to},
+$ES{from}->scan_scroll(
+    index => $INDEX{from},
+    body => { size => 1000 },
+    on_response => sub {
+        my ($status, $res) = @_;
+
+        my $body = [
+            map {(
+                { create => { _type => $_->{_type},  _id => $_->{_id}, } },
+                $_->{_source}
+            )} @{ $res->{hits}{hits} }
+        ];
+        my ($s2, $r2) = $ES{to}->bulk(
+            index => $INDEX{to},
+            body => $body
+        );
+
+        if ($status ne "200") {
+            croak "Failed to put documents to $OPT{to} (http status = $status): " . $JSON->encode([ $s2, $r2 ]);
+        }
+
+        show_counts( scalar @{$res->{hits}{hits}} );
+
+        return 1;
+    }
+);
+
+print "Optimizing $INDEX{to}.\n";
+$ES{to}->post(
+    index   => $INDEX{to},
+    command => "_optimize",
+    body => {
         max_num_segments => 1,
         wait_for_merge   => 0,
-    );
-};
+    }
+);
 
 sub show_counts {
-    my $doc = shift;
+    my $inc_records = shift;
 
     output({color=>'green'}, "Starting copy of $INDEX{from} to $OPT{to}:$INDEX{to}.") if $RECORDS == 0;
 
-    $RECORDS++;
+    $RECORDS += $inc_records;
     if( $RECORDS % 100_000 == 0 ) {
         my $now = time;
         my $diff = $now - $LAST;
@@ -107,38 +127,21 @@ sub show_counts {
         output({color=>'yellow'}, $msg);
         $LAST=$now;
     }
-    return $doc;
-}
-
-
-sub valid_index {
-    my ($index) = @_;
-
-    my $result;
-    eval {
-        $result = $ES{from}->index_exists( index => $index );
-        debug("$index", Dump($result));
-    };
-    if( my $error = $@ ) {
-        output({color=>'red',stderr=>1}, $error);
-    }
-    if( defined $result && exists $result->{ok} && $result->{ok} ) {
-        return 1;
-    }
-    return 0;
 }
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 es-copy-index.pl - Copy an index from one cluster to another
 
 =head1 VERSION
 
-version 1.5
+version 3.8
 
 =head1 SYNOPSIS
 
@@ -151,7 +154,14 @@ Options:
     --rename            Change the name of the index on the destination
     --help              print help
     --manual            print full manual
-    --verbose           Send additional messages to STDERR
+
+From CLI::Helpers:
+
+    --data-file         Path to a file to write lines tagged with 'data => 1'
+    --color             Boolean, enable/disable color, default use git settings
+    --verbose           Incremental, increase verbosity
+    --debug             Show developer output
+    --quiet             Show no output (for cron)
 
 =head1 DESCRIPTION
 
